pub struct AsyncPlasticityExecutor { /* private fields */ }Expand description
Async plasticity executor for std environments
Runs plasticity computation in a background thread, allowing the burst loop to continue processing while patterns are detected and memory neurons created.
This is optimal for CPU/GPU backends where:
- FireLedger is CPU-resident
- Plasticity computation can overlap with GPU burst processing
- Thread overhead is acceptable
Implementations
Sourceimpl AsyncPlasticityExecutor
impl AsyncPlasticityExecutor
Sourcepub fn new(
config: PlasticityConfig,
memory_stats_cache: MemoryStatsCache,
npu: Arc<TracingMutex<DynamicNPU>>,
) -> Self
pub fn new( config: PlasticityConfig, memory_stats_cache: MemoryStatsCache, npu: Arc<TracingMutex<DynamicNPU>>, ) -> Self
Create a new async plasticity executor
Sourcepub fn get_memory_stats_cache(&self) -> MemoryStatsCache
pub fn get_memory_stats_cache(&self) -> MemoryStatsCache
Get the memory stats cache
pub fn enqueue_commands_for_test(&self, commands: Vec<PlasticityCommand>)